<?php

namespace Drupal\language_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\LanguageFormatter;
use Drupal\Core\Entity\FieldableEntityInterface;

/**
 * Plugin for the 'original_language_translation_counter' formatter.
 *
 * @FieldFormatter(
 *   id = "original_language_translation_counter",
 *   label = @Translation("Original language with translation counter"),
 *   field_types = {
 *     "language"
 *   }
 * )
 */
class OriginalLanguageTranslationCounterFormatter extends LanguageFormatter {
  /**
   * {@inheritdoc}
   */
  protected function viewValue(FieldItemInterface $item) {
    return [
      '#markup' => $this->buildMarkup($item->getEntity()),
      '#attached' => ['library' => ['language_display/language_display']]
    ];
  }

  /**
   * Build markup for the field formatter.
   *
   * @param FieldableEntityInterface $entity
   *   Fieldable entity.
   *
   * @return string
   *   Markup string.
   */
  protected function buildMarkup(FieldableEntityInterface $entity) {
    $markup = '<span class="language-name">';
    $markup .= $this->languageManager->getDefaultLanguage()->getName();
    $markup .= '</span>';
    $translations = $entity->getTranslationLanguages(FALSE);
    $translations--;
    if(count($translations) > 0){
      $markup .= '<span class="translation-counter">';
      $markup .= $this->getStringTranslation()
        ->formatPlural(
          count($translations),
          '1 translation',
          '@count translations'
        );
      $markup .= '</span>';
    }
    return $markup;
  }
}
